<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>尾頁</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>點擊任意圖片以跳轉至相應書簽位置</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation>恢復默認</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>更改快捷鍵: 雙擊按鍵組合並輸入新的映射.</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation>快捷鍵設置</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>快捷鍵被佔用</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>快捷鍵 &quot;%1&quot; 已被映射至其他功能</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>第 %1 頁 CRC 校驗失敗: 部分頁面將無法正確顯示</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation>打開檔時出現未知錯誤</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>未找到 7z</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation>不支持的檔格式</translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>頁碼 : </translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>跳轉</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>總頁數: </translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>跳轉至 ...</translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>頁碼 : </translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="27"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="30"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="33"/>
        <source>System info</source>
        <translation>系統資訊</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation>日誌窗口</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation>中止(&amp;P)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation>清空(&amp;l)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation>複製(&amp;C)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation>等級:</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation>自動滾動(&amp;A)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>頁面流尺寸</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>我的漫畫路徑</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="61"/>
        <source>Background color</source>
        <translation>背景顏色</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="64"/>
        <source>Choose</source>
        <translation>選擇</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="99"/>
        <source>Quick Navigation Mode</source>
        <translation>快速導航模式</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="100"/>
        <source>Disable mouse over activation</source>
        <translation>禁用滑鼠啟動</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="199"/>
        <source>Restart is needed</source>
        <translation>需要重啟</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="143"/>
        <source>Brightness</source>
        <translation>亮度</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="71"/>
        <source>Scroll behaviour</source>
        <translation>滾動效果</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="74"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="75"/>
        <source>Do not turn page using scroll</source>
        <translation>滾動時不翻頁</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="76"/>
        <source>Use single scroll step to turn page</source>
        <translation>使用單滾動步驟翻頁</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="144"/>
        <source>Contrast</source>
        <translation>對比度</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="145"/>
        <source>Gamma</source>
        <translation>Gamma值</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="149"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="154"/>
        <source>Image options</source>
        <translation>圖片選項</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="158"/>
        <source>Fit options</source>
        <translation>適應項</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="160"/>
        <source>Enlarge images to fit width/height</source>
        <translation>放大圖片以適應寬度/高度</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="171"/>
        <source>Double Page options</source>
        <translation>雙頁選項</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="173"/>
        <source>Show covers as single page</source>
        <translation>顯示封面為單頁</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="191"/>
        <source>General</source>
        <translation>常規</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Page Flow</source>
        <translation>頁面流</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="193"/>
        <source>Image adjustment</source>
        <translation>圖像調整</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="208"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="215"/>
        <source>Comics directory</source>
        <translation>漫畫目錄</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation>未找到 7z 庫檔</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>無法從 ./utils 載入 7z 庫檔</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation>追蹤</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation>資訊</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation>嚴重錯誤</translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation>時間</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation>等級</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation>資訊</translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation>中止(&amp;P)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation>恢復(&amp;R)</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation>保存日誌</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation>日誌檔 (*.log)</translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">YACReader 鍵盤快捷鍵</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">關閉</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">鍵盤快捷鍵</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="924"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>按下 &apos;O&apos; 以打開漫畫.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Not found</source>
        <translation>未找到</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Comic not found</source>
        <translation>未找到漫畫</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="240"/>
        <source>Error opening comic</source>
        <translation>打開漫畫時發生錯誤</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>CRC Error</source>
        <translation>CRC 校驗失敗</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="936"/>
        <source>Loading...please wait!</source>
        <translation>載入中... 請稍候!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="946"/>
        <source>Page not available!</source>
        <translation>頁面不可用!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1128"/>
        <source>Cover!</source>
        <translation>封面!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1142"/>
        <source>Last page!</source>
        <translation>尾頁!</translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="183"/>
        <source>&amp;Open</source>
        <translation>打開(&amp;O)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="185"/>
        <source>Open a comic</source>
        <translation>打開漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="191"/>
        <source>New instance</source>
        <translation>新建實例</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="210"/>
        <source>Open Folder</source>
        <translation>打開檔夾</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="212"/>
        <source>Open image folder</source>
        <translation>打開圖片檔夾</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="217"/>
        <source>Open latest comic</source>
        <translation>打開最近的漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="218"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation>打開最近閱讀漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="230"/>
        <source>Clear</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="231"/>
        <source>Clear open recent list</source>
        <translation>清空最近訪問列表</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="236"/>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Save current page</source>
        <translation>保存當前頁面</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="241"/>
        <source>Previous Comic</source>
        <translation>上一個漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="243"/>
        <location filename="main_window_viewer.cpp" line="1641"/>
        <location filename="main_window_viewer.cpp" line="1645"/>
        <source>Open previous comic</source>
        <translation>打開上一個漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="248"/>
        <source>Next Comic</source>
        <translation>下一個漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="250"/>
        <location filename="main_window_viewer.cpp" line="1640"/>
        <location filename="main_window_viewer.cpp" line="1646"/>
        <source>Open next comic</source>
        <translation>打開下一個漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="255"/>
        <source>&amp;Previous</source>
        <translation>上一頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="258"/>
        <location filename="main_window_viewer.cpp" line="1643"/>
        <location filename="main_window_viewer.cpp" line="1647"/>
        <source>Go to previous page</source>
        <translation>轉至上一頁</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="263"/>
        <source>&amp;Next</source>
        <translation>下一頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="266"/>
        <location filename="main_window_viewer.cpp" line="1642"/>
        <location filename="main_window_viewer.cpp" line="1648"/>
        <source>Go to next page</source>
        <translation>轉至下一頁</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="271"/>
        <source>Fit Height</source>
        <translation>適應高度</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="274"/>
        <source>Fit image to height</source>
        <translation>縮放圖片以適應高度</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="281"/>
        <source>Fit Width</source>
        <translation>適合寬度</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="284"/>
        <source>Fit image to width</source>
        <translation>縮放圖片以適應寬度</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="291"/>
        <source>Show full size</source>
        <translation>顯示全尺寸</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="299"/>
        <source>Fit to page</source>
        <translation>適應頁面</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="330"/>
        <source>Reset zoom</source>
        <translation>重置縮放</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="335"/>
        <source>Show zoom slider</source>
        <translation>顯示縮放滑塊</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="338"/>
        <source>Zoom+</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="343"/>
        <source>Zoom-</source>
        <translation>縮小</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="348"/>
        <source>Rotate image to the left</source>
        <translation>向左旋轉圖片</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="354"/>
        <source>Rotate image to the right</source>
        <translation>向右旋轉圖片</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="360"/>
        <source>Double page mode</source>
        <translation>雙頁模式</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="361"/>
        <source>Switch to double page mode</source>
        <translation>切換至雙頁模式</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="370"/>
        <source>Double page manga mode</source>
        <translation>雙頁漫畫模式</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="371"/>
        <source>Reverse reading order in double page mode</source>
        <translation>雙頁模式 (逆序閱讀)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="380"/>
        <source>Go To</source>
        <translation>跳轉</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="382"/>
        <source>Go to page ...</source>
        <translation>跳轉至頁面 ...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="387"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="388"/>
        <source>YACReader options</source>
        <translation>YACReader 選項</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="395"/>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="396"/>
        <source>Help, About YACReader</source>
        <translation>幫助, 關於 YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="402"/>
        <source>Magnifying glass</source>
        <translation>放大鏡</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="403"/>
        <source>Switch Magnifying glass</source>
        <translation>切換放大鏡</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="410"/>
        <source>Set bookmark</source>
        <translation>設置書簽</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="411"/>
        <source>Set a bookmark on the current page</source>
        <translation>在當前頁面設置書簽</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="420"/>
        <source>Show bookmarks</source>
        <translation>顯示書簽</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="421"/>
        <source>Show the bookmarks of the current comic</source>
        <translation>顯示當前漫畫的書簽</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="427"/>
        <source>Show keyboard shortcuts</source>
        <translation>顯示鍵盤快捷鍵</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="433"/>
        <source>Show Info</source>
        <translation>顯示資訊</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="439"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="445"/>
        <source>Show Dictionary</source>
        <translation>顯示字典</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="452"/>
        <source>Show go to flow</source>
        <translation>顯示頁面流</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="458"/>
        <source>Edit shortcuts</source>
        <translation>編輯快捷鍵</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="481"/>
        <source>&amp;File</source>
        <translation>檔(&amp;F)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="493"/>
        <location filename="main_window_viewer.cpp" line="644"/>
        <source>Open recent</source>
        <translation>最近打開的檔</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="633"/>
        <source>File</source>
        <translation>檔</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="654"/>
        <source>Edit</source>
        <translation>編輯</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="658"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="674"/>
        <source>Go</source>
        <translation>轉到</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="682"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Open Comic</source>
        <translation>打開漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Comic files</source>
        <translation>漫畫檔</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="876"/>
        <source>Open folder</source>
        <translation>打開檔夾</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>page_%1.jpg</source>
        <translation>page_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Image files (*.jpg)</source>
        <translation>圖像檔 (*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1137"/>
        <source>Comics</source>
        <translation>漫畫</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1147"/>
        <source>Toggle fullscreen mode</source>
        <translation>切換全屏模式</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1150"/>
        <source>Hide/show toolbar</source>
        <translation>隱藏/顯示 工具欄</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1153"/>
        <source>General</source>
        <translation>常規</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1172"/>
        <source>Size up magnifying glass</source>
        <translation>增大放大鏡尺寸</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1175"/>
        <source>Size down magnifying glass</source>
        <translation>減小放大鏡尺寸</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1178"/>
        <source>Zoom in magnifying glass</source>
        <translation>增大縮放級別</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1181"/>
        <source>Zoom out magnifying glass</source>
        <translation>減小縮放級別</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1187"/>
        <source>Magnifiying glass</source>
        <translation>放大鏡</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1194"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation>切換顯示為&quot;適應寬度&quot;或&quot;適應高度&quot;</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1198"/>
        <source>Page adjustement</source>
        <translation>頁面調整</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1215"/>
        <source>Autoscroll down</source>
        <translation>向下自動滾動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Autoscroll up</source>
        <translation>向上自動滾動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1221"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation>向前自動滾動，水準優先</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation>向後自動滾動，水準優先</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Autoscroll forward, vertical first</source>
        <translation>向前自動滾動，垂直優先</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1233"/>
        <source>Autoscroll backward, vertical first</source>
        <translation>向後自動滾動，垂直優先</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1237"/>
        <source>Move down</source>
        <translation>向下移動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1240"/>
        <source>Move up</source>
        <translation>向上移動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1243"/>
        <source>Move left</source>
        <translation>向左移動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Move right</source>
        <translation>向右移動</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Go to the first page</source>
        <translation>轉到第一頁</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Go to the last page</source>
        <translation>轉到最後一頁</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1255"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1257"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1275"/>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1320"/>
        <source>There is a new version available</source>
        <translation>有新版本可用</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1321"/>
        <source>Do you want to download the new version?</source>
        <translation>你要下載新版本嗎?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1324"/>
        <source>Remind me in 14 days</source>
        <translation>14天後提醒我</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1325"/>
        <source>Not now</source>
        <translation>現在不</translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="115"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>點擊以覆蓋</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>恢復默認</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>點擊以覆蓋</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>恢復默認</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>封面顯示方式:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>封面流</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>條狀</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>重疊條狀</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>預設:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>經典</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>條狀</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>重疊條狀</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>現代</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>輪盤</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>顯示高級選項</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>自定義:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>視角</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>封面間距</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>中心間距</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>縮放</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Y位移</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Z位移</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>封面角度</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>透明度</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>亮度</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>最大角度</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>低性能</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>高性能</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>使用VSync (在全屏模式下提高圖像品質, 性能更差)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>性能:</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation>編輯快捷鍵</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>使用硬體加速 (需要重啟)</translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation>YACReader 翻譯</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation>翻譯</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation>服務不可用</translation>
    </message>
</context>
</TS>
